# -*- coding: utf-8 -*-

import sys
import os

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.

pism_build_dir = os.getenv("PISM_BUILD_DIR")
assert pism_build_dir is not None

# path to PISM's bindings in the build directory
sys.path.insert(0, os.path.abspath(os.path.join(pism_build_dir, "site-packages")))

# -- General configuration -----------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be extensions
# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = ['sphinx.ext.autodoc',
              'sphinx.ext.graphviz',
              'sphinx.ext.inheritance_diagram',
              'sphinx.ext.mathjax',
              'sphinxcontrib.bibtex']

# Add a couple of new rst roles for config variables and NC file variables.
# They will be formatted using rules in PISM.css
rst_prolog = """
.. role:: cfg

.. role:: ncvar
"""

# -- Inheritance graphs ----------------------------------------------------------

inheritance_graph_attrs = dict(rankdir="TD")

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix of source filenames.
source_suffix = '.rst'

# The encoding of source files.
#source_encoding = 'utf-8-sig'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = "PISM's Python bindings and inversion tools"
copyright = '2013--2018, PISM Authors'

# List code generated by autodoc in the order it occurs in the source files,
# not the default (alphabetical).
autodoc_member_order = 'bysource'

# When automatically generating class documentation, include both the
# class docstring and the __init__ docstring.
autoclass_content = 'both'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
version = 'v1.1'
# The full version, including alpha/beta/rc tags.
release = 'v1.1'

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = ['_build']

# The reST default role (used for this markup: `text`) to use for all documents.
#default_role = None

# -- Options for HTML output ---------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme_path = ['.']
html_theme = 'pismdoc'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static', 'pismdoc']
